@@ -28,11 +28,11 @@
 ##############################################################################
 package XML::Stream::XPath::Op;
 
-use 5.006_001;
+use 5.008;
 use strict;
 use vars qw( $VERSION );
 
-$VERSION = "1.21";
+$VERSION = "1.23";
 
 sub new
 {
@@ -105,6 +105,7 @@ sub new
     my $proto = shift;
     my $self = $proto->allocate("POSITION","");
     $self->{POS} = shift;
+
     return $self;
 }
 
